@@ -41,13 +41,16 @@ def test_conda_run_command(cmd, initproj):
                 [tox]
                 skipsdist=True
                 [testenv:{}]
-                deps = pip>0,<999
+                deps =
+                    pip>0,<999
+                    -r requirements.txt
                 commands_pre = python -c "import os; open('commands_pre', 'w').write(os.environ['CONDA_PREFIX'])"
                 commands = python -c "import os; open('commands', 'w').write(os.environ['CONDA_PREFIX'])"
                 commands_post = python -c "import os; open('commands_post', 'w').write(os.environ['CONDA_PREFIX'])"
             """.format(  # noqa: E501
                 env_name
-            )
+            ),
+            "requirements.txt": "",
         },
     )
 
